==> 0.8.1.tar.gz: lib/model/tree.dart <==
part of tags;

abstract class Tree<T> {
  
// -----------------------------------------------------------------------------
// Implemented in the TreeView base class; not designed for override.
// -----------------------------------------------------------------------------
  
  T get data;  
  List<Tree> get logicalChildren;
  Tree get logicalParent;  
  bool isExpanded;
  
  void initialize(T data, [Tree logicalParent]);
  void shutdown();
  
  /// Builds this tree's [logicalChildren] but does not render them.
  Future buildChildren();
  
  void refresh();  
  void removeChildren(bool predicate(Tree tree));
  void renderChildren();
  void toggleExpanded();
  
  /// Expands this tree recursively until a tree with the given [data] is found.  
  /// Completes `true` if the [data] is found recursively in this tree.
  Future<bool> expandTo(data);
    
// -----------------------------------------------------------------------------
// Stubbed in the TreeView base class and designed for override.
// -----------------------------------------------------------------------------
  
  Command get copy;
  Command get cut;
  Command get delete;
  Command get paste;
  Command get rename;
  
  void initialize_(T data);
  void shutdown_();  
  
  void showContextMenu_();
  void hideContextMenu_();
  
  void singleClick_();
  void doubleClick_();
  
  void collapse_();
  void expand_();
  
  void attached_();
  void detached_();
  
  void select_();
  void unselect_();
  
  Future buildChildren_();
}

==> 0.8.3.tar.gz: lib/model/tree.dart <==
part of tags;

abstract class Tree<T> {
  
// -----------------------------------------------------------------------------
// Implemented in the TreeView base class; not designed for override.
// -----------------------------------------------------------------------------
  
  T get data;  
  List<Tree> get logicalChildren;
  Tree get logicalParent;  
  bool isExpanded;
  
  void initialize(T data, [Tree logicalParent]);
  void shutdown();
  
  /// Builds this tree's [logicalChildren] but does not render them.
  Future buildChildren();
  
  void refresh();  
  void removeChildren(bool predicate(Tree tree));
  void renderChildren();
  void toggleExpanded();
  
  /// Expands this tree recursively until a tree that matches the given 
  /// [predicate] is found.  
  /// Completes `true` if the [predicate] returns `true` once in this tree.
  Future<bool> expandTo(bool predicate(Tree tree));
    
// -----------------------------------------------------------------------------
// Stubbed in the TreeView base class and designed for override.
// -----------------------------------------------------------------------------
  
  Command get copy;
  Command get cut;
  Command get delete;
  Command get paste;
  Command get rename;
  
  void initialize_(T data);
  void shutdown_();  
  
  void showContextMenu_();
  void hideContextMenu_();
  
  void singleClick_();
  void doubleClick_();
  
  void collapse_();
  void expand_();
  
  void attached_();
  void detached_();
  
  void select_();
  void unselect_();
  
  Future buildChildren_();
}
